﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Drawing;
using System.Xml.Linq;
using MindFusion.Drawing;
using MindFusion.Diagramming;
using MindFusion.Diagramming.Layout;
using MindFusion.Diagramming.Mvc;

namespace BorderedTreeLayout.Controllers
{
    public class HomeController : Controller
    {
        public ActionResult Index()
        {
            DiagramView view = new DiagramView("diagramView1");

            Diagram diagram = view.Diagram;
            diagram.Bounds = new RectangleF(0, 0, 500, 800);
            diagram.ShapeNodeStyle.Brush = new MindFusion.Drawing.SolidBrush(ColorTranslator.FromHtml("#e0e9e9"));
            diagram.ShapeNodeStyle.FontSize = 25;
            diagram.ShapeNodeStyle.FontFamily = "Arial";
            diagram.ShapeNodeStyle.FontUnit = GraphicsUnit.Pixel;
            diagram.ShapeNodeStyle.Effects.Add(new GlassEffect());

            var root = diagram.Factory.CreateShapeNode(new RectangleF(0, 0, 70, 10));
            root.Text = "Project";
            var document = XDocument.Load(Server.MapPath("~/BorderedTreeLayout.xml"));
            CreateChildren(diagram, root, document.Element("Project"));

            TreeLayout layout = new TreeLayout();
            layout.Type = TreeLayoutType.Cascading;
            layout.Direction = TreeLayoutDirections.LeftToRight;
            layout.LinkStyle = TreeLayoutLinkType.Cascading2;
            layout.NodeDistance = 1;
            layout.LevelDistance = -8; // let horizontal positions overlap
            layout.Arrange(diagram);
            diagram.ResizeToFitItems(8);

            view.ZoomFactor = 60;

            ViewBag.DiagramView = view;
            return View();
        }

        private void CreateChildren(Diagram diagram, DiagramNode parentDiagNode, XElement parentXmlElement)
        {
            foreach (var element in parentXmlElement.Elements("Activity"))
            {
                var node = diagram.Factory.CreateShapeNode(new RectangleF(0, 0, 70, 10));
                node.Text = element.Attribute("Name").Value;
                diagram.Factory.CreateDiagramLink(parentDiagNode, node);
                CreateChildren(diagram, node, element);
            }
        }
    }
}